# Xplt

<!--[![Contributors](https://img.shields.io/github/contributors/xsuite/xplt)](https://github.com/xsuite/xplt/graphs/contributors)-->
[![Build status](https://img.shields.io/github/actions/workflow/status/xsuite/xplt/test.yaml?branch=main)](https://github.com/xsuite/xplt/actions)
[![Pip version](https://img.shields.io/pypi/v/xplt?label=pip)](https://pypi.org/project/xplt)

<img width="40%" align="right" src="https://github.com/xsuite/xplt/raw/main/.github/sampleplot.png"/>

A plotting library for [Xsuite](https://github.com/xsuite) and simmilar accelerator physics codes.


## Usage

```bash
pip install xplt[recommended]
```

Read the docs at https://xsuite.github.io/xplt



## Developers and Contributors

See the wiki page at https://github.com/xsuite/xplt/wiki
